@@ -3,7 +3,7 @@
 //! # Example
 //!
 //! ```rust
-//! # #[async_std::main] async fn main() -> Result<(), Box<dyn std::error::Error>> {
+//! # #[tokio::main] async fn main() -> Result<(), Box<dyn std::error::Error>> {
 //! let client = ytextract::Client::new();
 //!
 //! let streams = client.streams("nI2e-J6fsuk".parse()?).await?;
@@ -29,7 +29,7 @@ pub(crate) async fn get(
     client: Client,
     id: crate::video::Id,
 ) -> crate::Result<impl Iterator<Item = Stream>> {
-    let player_response = client.api.streams(id).await?.into_std()?;
+    let player_response = client.api.streams(id).await?;
 
     // TODO: DashManifest/HlsManifest
     Ok(player_response
